;; Quail packages for inputting various Code Page.
;; Copyright (C) 1997 Free Software Foundation, Inc.
;; This file is part of Mule (MULtilingual Enhancement of GNU Emacs).

;; Mule is free software distributed in the form of patches to GNU Emacs.
;; You can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 1, or (at your option)
;; any later version.

;; Mule is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;; 97.3.2  K.Fujii <JAE01012@niftyserve.or.jp>.

(require 'quail)

(quail-define-package "cp-437" "CP-437" t "Code Page 437 encoding.

    effect   | postfix | examples
 ------------+---------+----------
    acute    |    '    | a' -> ,Aa(B
    grave    |    `    | a` -> ,A`(B
  circumflex |    ^    | a^ -> ,Ab(B
  diaeresis  |    \"    | a\" -> ,Ad(B
    tilde    |    ~    | n~ -> ,Aq(B
   cedilla   |    ,    | c, -> ,Ag(B
   nordic    |    /    | a/ -> ,Ae(B   e/ -> ,Af(B   o/ -> ,Ax(B   s/ -> ,A_(B
   greek     |    .    | a. -> ,Fa(B   g. -> ,Fc(B   p. -> ,FP(B   s. -> ,FS(B
             |         | f. -> ,FV(B   u. -> ,FH(B   v. -> ,FY(B   d. -> ,Fd(B
   special   |   /<>   | ?/ -> ,A?(B   !/ -> ,A!(B   << -> ,A+(B   >> -> ,A;(B
             |         | 2/ -> ,A=(B   4/ -> ,A<(B   Y= -> ,A%(B   L/ -> ,A#(B   $/ -> ,A'(B
             |         | P/ -> ,A6(B   ]/ -> ,A,(B   // -> ,Aw(B   +/, -/ -> ,A1(B
             |   _     | a_ -> ,A*(B   o_ -> ,A:(B
             |   |     | C| -> ,A"(B
             |         | m/ -> ,Fl(B
" nil t)

(qd "A\"" ?,AD(B)
(qd "A/" ?,AE(B)
(qd "a'" ?,Aa(B)
(qd "a`" ?,A`(B)
(qd "a^" ?,Ab(B)
(qd "a/" ?,Ae(B)
(qd "a_" ?,A*(B)
(qd "a." ?,Fa(B)

(qd "C," ?,AG(B)
(qd "C|" ?,A"(B)
(qd "c," ?,Ag(B)

(qd "E'" ?,AI(B)
(qd "E/" ?,AF(B)
(qd "e'" ?,Ai(B)
(qd "e`" ?,Ah(B)
(qd "e^" ?,Aj(B)
(qd "e\"" ?,Ak(B)
(qd "e/" ?,Af(B)

(qd "d." ?,Fd(B)

(qd "f." ?,FV(B)

(qd "G." ?,FC(B)
(qd "g." ?,Fc(B)

(qd "i'" ?,Am(B)
(qd "i`" ?,Al(B)
(qd "i^" ?,An(B)
(qd "i\"" ?,Ao(B)

(qd "L/" ?,A#(B)

(qd "m/" ?,A5(B)

(qd "N~" ?,AQ(B)
(qd "n~" ?,Aq(B)

(qd "O\"" ?,AV(B)
(qd "o'" ?,As(B)
(qd "o`" ?,Ar(B)
(qd "o^" ?,At(B)
(qd "o\"" ?,Av(B)
(qd "o_" ?,A:(B)

(qd "P/" ?,A6(B)
(qd "P." ?,FP(B)

(qd "S." ?,FS(B)
(qd "s." ?,Fs(B)
(qd "s/" ?,A_(B)

(qd "U\"" ?,A\(B)
(qd "U." ?,Fh(B)

(qd "u'" ?,Az(B)
(qd "u`" ?,Ay(B)
(qd "u^" ?,A{(B)
(qd "u\"" ?,A|(B)

(qd "V." ?,FY(B)

(qd "Y=" ?,A%(B)
(qd "y\"" ?,A(B)

(qd "!/" ?,A!(B)
(qd "$/" ?,A'(B)
(qd "//" ?,Aw(B)
(qd "+/" ?,A1(B)
(qd "-/" ?,A1(B)
(qd "2/" ?,A=(B)
(qd "4/" ?,A<(B)
(qd "<<" ?,A+(B)
(qd ">>" ?,A;(B)
(qd "?/" ?,A?(B)
(qd "]/" ?,A,(B)

(quail-setup-current-package)


(quail-define-package "cp-850" "CP-850" t "Code Page 850 encoding.

    effect   | postfix | examples
 ------------+---------+----------
    acute    |    '    | a' -> ,Aa(B
    grave    |    `    | a` -> ,A`(B
  circumflex |    ^    | a^ -> ,Ab(B
  diaeresis  |    \"    | a\" -> ,Ad(B
    tilde    |    ~    | n~ -> ,Aq(B
   cedilla   |    ,    | c, -> ,Ag(B
   nordic    |    /    | d/ -> ,Ap(B   t/ -> ,A~(B   a/ -> ,Ae(B   e/ -> ,Af(B   o/ -> ,Ax(B
   special   |   /<>   | ?/ -> ,A?(B   !/ -> ,A!(B   << -> ,A+(B   >> -> ,A;(B   p/ -> ,A6(B
             |         | 2/ -> ,A=(B   4/ -> ,A<(B   3/ -> ,A>(B   Y= -> ,A%(B   L/ -> ,A#(B
             |         | */ -> ,AW(B   // -> ,Aw(B   +/ -> ,A1(B   -/ -> ,A-(B   ./ -> ,A$(B
             |         | s/ -> ,A_(B   $/ -> ,A'(B   ]/ -> ,A,(B
             |    _    | a_ -> ,A*(B   o_ -> ,A:(B
             |    |    | C| -> ,A"(B
             |    .    | C. -> ,A)(B   R. -> ,A.(B
             |         | m/ -> ,Fl(B
" nil t)

(qd "A\"" ?,AD(B)
(qd "A/" ?,AE(B)
(qd "a'" ?,Aa(B)
(qd "a`" ?,A`(B)
(qd "a^" ?,Ab(B)
(qd "a\"" ?,Ad(B)
(qd "a/" ?,Ae(B)
(qd "a_" ?,A*(B)

(qd "C," ?,AG(B)
(qd "C|" ?,A"(B)
(qd "C." ?,A)(B)
(qd "c," ?,Ag(B)

(qd "D/" ?,AP(B)
(qd "d/" ?,Ap(B)

(qd "E'" ?,AI(B)
(qd "E`" ?,AH(B)
(qd "E^" ?,AJ(B)
(qd "E\"" ?,AK(B)
(qd "E/" ?,AF(B)
(qd "e'" ?,Ai(B)
(qd "e`" ?,Ah(B)
(qd "e^" ?,Aj(B)
(qd "e\"" ?,Ak(B)
(qd "e/" ?,Af(B)

(qd "I'" ?,AM(B)
(qd "I`" ?,AL(B)
(qd "I^" ?,AN(B)
(qd "I\"" ?,AO(B)
(qd "i'" ?,Am(B)
(qd "i`" ?,Al(B)
(qd "i^" ?,An(B)
(qd "i\"" ?,Ao(B)

(qd "L/" ?,A#(B)

(qd "m/" ?,A5(B)

(qd "N~" ?,AQ(B)
(qd "n~" ?,Aq(B)

(qd "O~" ?,AU(B)
(qd "O\"" ?,AV(B)
(qd "O/" ?,AX(B)
(qd "o'" ?,As(B)
(qd "o`" ?,Ar(B)
(qd "o^" ?,At(B)
(qd "o\"" ?,Av(B)
(qd "o/" ?,Ax(B)
(qd "o_" ?,A:(B)

(qd "P/" ?,A6(B)

(qd "R." ?,A.(B)

(qd "s/" ?,A_(B)

(qd "T/" ?,A^(B)
(qd "t/" ?,A~(B)

(qd "U'" ?,AZ(B)
(qd "U`" ?,AY(B)
(qd "U^" ?,A[(B)
(qd "U\"" ?,A\(B)
(qd "u'" ?,Az(B)
(qd "u`" ?,Ay(B)
(qd "u^" ?,A{(B)
(qd "u\"" ?,A|(B)

(qd "Y'" ?,A](B)
(qd "Y=" ?,A%(B)
(qd "y'" ?,A}(B)

(qd "!/" ?,A!(B)
(qd "?/" ?,A?(B)
(qd "$/" ?,A'(B)
(qd "//" ?,Aw(B)
(qd "*/" ?,AW(B)
(qd "<<" ?,A+(B)
(qd ">>" ?,A;(B)
(qd "+/" ?,A1(B)
(qd "-/" ?,A-(B)
(qd "./" ?,A$(B)
(qd "2/" ?,A=(B)
(qd "4/" ?,A<(B)
(qd "3/" ?,A>(B)
(qd "]/" ?,A,(B)

(quail-setup-current-package)


(quail-define-package "cp-852" "CP-852" t "Code Page 852 encoding.

    effect   | postfix | examples
 ------------+---------+----------
    acute    |    '    | a' -> ,Ba(B
    ogonek   |    ,    | a, -> ,B1(B
  diaeresis  |    \"    | a\" -> ,Bd(B
  circumflex |    ^    | a^ -> ,Bb(B
    breve    |    ~    | a~ -> ,Bc(B
   cedilla   |    ,    | c, -> ,Bg(B
    caron    |    ~    | c~ -> ,Bh(B
  dbl. acute |    ''   | o'' -> ,Bu(B
     ring    |    .    | u. -> ,By(B
     dot     |    .    | z. -> ,B?(B
    stroke   |    /    | d/ -> ,Bp(B
   special   |    /<>  | s/ -> ,B_(B  $/ -> ,B'(B  // -> ,Bw(B  */ -> ,BW(B
             |         | ./ -> ,B$(B  .. -> ,B0(B  << -> ,A+(B  >> -> ,A;(B
             |         | P/ -> ,A6(B
" nil t)

(qd "A'" ?,BA(B)
(qd "A," ?,B!(B)
(qd "A\"" ?,BD(B)
(qd "A^" ?,BB(B)
(qd "A~" ?,BC(B)
(qd "C'" ?,BF(B)
(qd "C," ?,BG(B)
(qd "C~" ?,BH(B)
(qd "D/" ?,BP(B)
(qd "D~" ?,BO(B)
(qd "E'" ?,BI(B)
(qd "E," ?,BJ(B)
(qd "E\"" ?,BK(B)
(qd "E~" ?,BL(B)
(qd "I'" ?,BM(B)
(qd "I^" ?,BN(B)
(qd "L'" ?,BE(B)
(qd "L/" ?,B#(B)
(qd "L~" ?,B%(B)
(qd "N'" ?,BQ(B)
(qd "N~" ?,BR(B)
(qd "O'" ?,BS(B)
(qd "O''" '(",BU(B" ",BS(B'"))
(qd "O\"" ?,BV(B)
(qd "O^" ?,BT(B)
(qd "P/" ?,A6(B)
(qd "R'" ?,B@(B)
(qd "R~" ?,BX(B)
(qd "S'" ?,B&(B)
(qd "S," ?,B*(B)
(qd "S~" ?,B)(B)
(qd "T," ?,B^(B)
(qd "T~" ?,B+(B)
(qd "U'" ?,BZ(B)
(qd "U''" '(",B[(B" ",BZ(B'"))
(qd "U\"" ?,B\(B)
(qd "U." ?,BY(B)
(qd "Y'" ?,B](B)
(qd "Z'" ?,B,(B)
(qd "Z." ?,B/(B)
(qd "Z~" ?,B.(B)
(qd "a'" ?,Ba(B)
(qd "a," ?,B1(B)
(qd "a\"" ?,Bd(B)
(qd "a^" ?,Bb(B)
(qd "a~" ?,Bc(B)
(qd "c'" ?,Bf(B)
(qd "c," ?,Bg(B)
(qd "c~" ?,Bh(B)
(qd "d/" ?,Bp(B)
(qd "d~" ?,Bo(B)
(qd "e'" ?,Bi(B)
(qd "e," ?,Bj(B)
(qd "e\"" ?,Bk(B)
(qd "e~" ?,Bl(B)
(qd "i'" ?,Bm(B)
(qd "i^" ?,Bn(B)
(qd "l'" ?,Be(B)
(qd "l/" ?,B3(B)
(qd "l~" ?,B5(B)
(qd "n'" ?,Bq(B)
(qd "n~" ?,Br(B)
(qd "o'" ?,Bs(B)
(qd "o''" '(",Bu(B" ",Bs(B'"))
(qd "o\"" ?,Bv(B)
(qd "o^" ?,Bt(B)
(qd "r'" ?,B`(B)
(qd "r~" ?,Bx(B)
(qd "s'" ?,B6(B)
(qd "s," ?,B:(B)
(qd "s/" ?,B_(B)
(qd "s~" ?,B9(B)
(qd "t," ?,B~(B)
(qd "t~" ?,B;(B)
(qd "u'" ?,Bz(B)
(qd "u''" '(",B{(B" ",Bz(B'"))
(qd "u\"" ?,B|(B)
(qd "u." ?,By(B)
(qd "y'" ?,B}(B)
(qd "z'" ?,B<(B)
(qd "z." ?,B?(B)
(qd "z~" ?,B>(B)
(qd "<<" ?,A+(B)
(qd ">>" ?,A;(B)
(qd "$/" ?,B'(B)
(qd "//" ?,Bw(B)
(qd "*/" ?,BW(B)
(qd "./" ?,B$(B)
(qd ".." ?,B0(B)

(quail-setup-current-package)


(quail-define-package "cp-860" "CP-860" t "Code Page 860 encoding.

    effect   | postfix | examples
 ------------+---------+----------
    acute    |    '    | a' -> ,Aa(B
    grave    |    `    | a` -> ,A`(B
  circumflex |    ^    | a^ -> ,Ab(B
  diaeresis  |    \"    | a\" -> ,Ad(B
    tilde    |    ~    | n~ -> ,Aq(B
   cedilla   |    ,    | c, -> ,Ag(B
   nordic    |    /    | o/ -> ,Ax(B   s/ -> ,A_(B
   greek     |    .    | a. -> ,Fa(B   g. -> ,Fc(B   p. -> ,FP(B   s. -> ,FS(B
             |         | f. -> ,FV(B   u. -> ,FH(B   v. -> ,FY(B   d. -> ,Fd(B
   special   |   /<>   | ?/ -> ,A?(B   !/ -> ,A!(B   << -> ,A+(B   >> -> ,A;(B
             |         | 2/ -> ,A=(B   4/ -> ,A<(B   L/ -> ,A#(B   $/ -> ,A'(B
             |         | P/ -> ,A6(B   ]/ -> ,A,(B   // -> ,Aw(B   +/, -/ -> ,A1(B
             |   _     | a_ -> ,A*(B   o_ -> ,A:(B
             |   |     | C| -> ,A"(B
             |         | m/ -> ,Fl(B
" nil t)

(qd "A\"" ?,AD(B)
(qd "A~" ?,AC(B)
(qd "a'" ?,Aa(B)
(qd "a`" ?,A`(B)
(qd "a^" ?,Ab(B)
(qd "a~" ?,Ac(B)
(qd "a_" ?,A*(B)
(qd "a." ?,Fa(B)

(qd "C," ?,AG(B)
(qd "C|" ?,A"(B)
(qd "c," ?,Ag(B)

(qd "E'" ?,AI(B)
(qd "E`" ?,AH(B)
(qd "E^" ?,AJ(B)
(qd "e'" ?,Ai(B)
(qd "e`" ?,Ah(B)
(qd "e^" ?,Aj(B)

(qd "d." ?,Fd(B)

(qd "f." ?,FV(B)

(qd "G." ?,FC(B)
(qd "g." ?,Fc(B)

(qd "I'" ?,AM(B)
(qd "I`" ?,AL(B)
(qd "i'" ?,Am(B)
(qd "i`" ?,Al(B)

(qd "L/" ?,A#(B)

(qd "m/" ?,A5(B)

(qd "N~" ?,AQ(B)
(qd "n~" ?,Aq(B)

(qd "O'" ?,AS(B)
(qd "O^" ?,AT(B)
(qd "O`" ?,AR(B)
(qd "O~" ?,AU(B)
(qd "o'" ?,As(B)
(qd "o`" ?,Ar(B)
(qd "o^" ?,At(B)
(qd "o~" ?,Au(B)
(qd "o_" ?,A:(B)

(qd "P/" ?,A6(B)
(qd "P." ?,FP(B)

(qd "S." ?,FS(B)
(qd "s." ?,Fs(B)
(qd "s/" ?,A_(B)

(qd "U'" ?,AZ(B)
(qd "U`" ?,AY(B)
(qd "U\"" ?,A\(B)
(qd "U." ?,Fh(B)

(qd "u'" ?,Az(B)
(qd "u`" ?,Ay(B)
(qd "u\"" ?,A|(B)

(qd "V." ?,FY(B)

(qd "!/" ?,A!(B)
(qd "$/" ?,A'(B)
(qd "//" ?,Aw(B)
(qd "+/" ?,A1(B)
(qd "-/" ?,A1(B)
(qd "2/" ?,A=(B)
(qd "4/" ?,A<(B)
(qd "<<" ?,A+(B)
(qd ">>" ?,A;(B)
(qd "?/" ?,A?(B)
(qd "]/" ?,A,(B)

(quail-setup-current-package)

(quail-define-package "cp-863" "CP-863" t "Code Page 863 encoding.

    effect   | postfix | examples
 ------------+---------+----------
    acute    |    '    | a' -> ,Aa(B
    grave    |    `    | a` -> ,A`(B
  circumflex |    ^    | a^ -> ,Ab(B
  diaeresis  |    \"    | e\" -> ,Ak(B
   cedilla   |    ,    | c, -> ,Ag(B
   greek     |    .    | a. -> ,Fa(B   g. -> ,Fc(B   p. -> ,FP(B   s. -> ,FS(B
             |         | f. -> ,FV(B   u. -> ,FH(B   v. -> ,FY(B   d. -> ,Fd(B
   special   |   /<>   | ?/ -> ,A?(B   !/ -> ,A!(B   << -> ,A+(B   >> -> ,A;(B
             |         | 2/ -> ,A=(B   4/ -> ,A<(B   3/ -> ,A>(B   L/ -> ,A#(B   $/ -> ,A'(B
             |         | P/ -> ,A6(B   ]/ -> ,A,(B   // -> ,Aw(B   +/, -/ -> ,A1(B
             |         | s/ -> ,A_(B   ./ -> ,A$(B   _/ -> ,A/(B   |/ -> ,A&(B
             |   .     | 2. -> ,A2(B   3. -> ,A3(B
             |   _     | a_ -> ,A*(B   o_ -> ,A:(B
             |   |     | C| -> ,A"(B
             |         | m/ -> ,Fl(B
" nil t)

(qd "A`" ?,A@(B)
(qd "A^" ?,AB(B)
(qd "a`" ?,A`(B)
(qd "a^" ?,Ab(B)
(qd "a_" ?,A*(B)
(qd "a." ?,Fa(B)

(qd "C," ?,AG(B)
(qd "C|" ?,A"(B)
(qd "c," ?,Ag(B)

(qd "E'" ?,AI(B)
(qd "E`" ?,AH(B)
(qd "E^" ?,AJ(B)
(qd "E\"" ?,AK(B)
(qd "e'" ?,Ai(B)
(qd "e`" ?,Ah(B)
(qd "e^" ?,Aj(B)
(qd "e\"" ?,Ak(B)

(qd "d." ?,Fd(B)

(qd "f." ?,FV(B)

(qd "G." ?,FC(B)
(qd "g." ?,Fc(B)

(qd "I^" ?,AN(B)
(qd "I\"" ?,AO(B)
(qd "i^" ?,An(B)
(qd "i\"" ?,Ao(B)

(qd "L/" ?,A#(B)

(qd "m/" ?,A5(B)

(qd "O^" ?,AT(B)
(qd "o'" ?,As(B)
(qd "o^" ?,At(B)
(qd "o_" ?,A:(B)

(qd "P/" ?,A6(B)
(qd "P." ?,FP(B)

(qd "S." ?,FS(B)
(qd "s." ?,Fs(B)
(qd "s/" ?,A_(B)

(qd "U`" ?,AY(B)
(qd "U^" ?,A[(B)
(qd "U\"" ?,A\(B)
(qd "U." ?,Fh(B)

(qd "u'" ?,Az(B)
(qd "u`" ?,Ay(B)
(qd "u^" ?,A{(B)
(qd "u\"" ?,A|(B)

(qd "V." ?,FY(B)

(qd "!/" ?,A!(B)
(qd "$/" ?,A'(B)
(qd "//" ?,Aw(B)
(qd "+/" ?,A1(B)
(qd "-/" ?,A1(B)
(qd "2/" ?,A=(B)
(qd "4/" ?,A<(B)
(qd "3/" ?,A>(B)
(qd "2." ?,A2(B)
(qd "3." ?,A3(B)
(qd "_/" ?,A/(B)
(qd "<<" ?,A+(B)
(qd ">>" ?,A;(B)
(qd "?/" ?,A?(B)
(qd "]/" ?,A,(B)
(qd "|/" ?,A&(B)
(qd "./" ?,A$(B)

(quail-setup-current-package)

(quail-define-package "cp-865" "CP-865" t "Code Page 865 encoding.

    effect   | postfix | examples
 ------------+---------+----------
    acute    |    '    | a' -> ,Aa(B
    grave    |    `    | a` -> ,A`(B
  circumflex |    ^    | a^ -> ,Ab(B
  diaeresis  |    \"    | a\" -> ,Ad(B
    tilde    |    ~    | n~ -> ,Aq(B
   cedilla   |    ,    | c, -> ,Ag(B
   nordic    |    /    | a/ -> ,Ae(B   e/ -> ,Af(B   o/ -> ,Ax(B   s/ -> ,A_(B
   greek     |    .    | a. -> ,Fa(B   g. -> ,Fc(B   p. -> ,FP(B   s. -> ,FS(B
             |         | f. -> ,FV(B   u. -> ,FH(B   v. -> ,FY(B   d. -> ,Fd(B
   special   |   /<>   | ?/ -> ,A?(B   !/ -> ,A!(B   << -> ,A+(B   ./ -> ,A$(B
             |         | 2/ -> ,A=(B   4/ -> ,A<(B   L/ -> ,A#(B   $/ -> ,A'(B
             |         | P/ -> ,A6(B   ]/ -> ,A,(B   // -> ,Aw(B   +/, -/ -> ,A1(B
             |   _     | a_ -> ,A*(B   o_ -> ,A:(B
             |   .     | 2. -> ,A2(B
             |         | m/ -> ,Fl(B
" nil t)

(qd "A\"" ?,AD(B)
(qd "A/" ?,AE(B)
(qd "a'" ?,Aa(B)
(qd "a`" ?,A`(B)
(qd "a^" ?,Ab(B)
(qd "a/" ?,Ae(B)
(qd "a_" ?,A*(B)
(qd "a." ?,Fa(B)

(qd "C," ?,AG(B)
(qd "c," ?,Ag(B)

(qd "E'" ?,AI(B)
(qd "E/" ?,AF(B)
(qd "e'" ?,Ai(B)
(qd "e`" ?,Ah(B)
(qd "e^" ?,Aj(B)
(qd "e\"" ?,Ak(B)
(qd "e/" ?,Af(B)

(qd "d." ?,Fd(B)

(qd "f." ?,FV(B)

(qd "G." ?,FC(B)
(qd "g." ?,Fc(B)

(qd "i'" ?,Am(B)
(qd "i`" ?,Al(B)
(qd "i^" ?,An(B)
(qd "i\"" ?,Ao(B)

(qd "L/" ?,A#(B)

(qd "m/" ?,A5(B)

(qd "N~" ?,AQ(B)
(qd "n~" ?,Aq(B)

(qd "O\"" ?,AV(B)
(qd "o'" ?,As(B)
(qd "o`" ?,Ar(B)
(qd "o^" ?,At(B)
(qd "o\"" ?,Av(B)
(qd "o_" ?,A:(B)

(qd "P/" ?,A6(B)
(qd "P." ?,FP(B)

(qd "S." ?,FS(B)
(qd "s." ?,Fs(B)
(qd "s/" ?,A_(B)

(qd "U\"" ?,A\(B)
(qd "U." ?,Fh(B)

(qd "u'" ?,Az(B)
(qd "u`" ?,Ay(B)
(qd "u^" ?,A{(B)
(qd "u\"" ?,A|(B)

(qd "V." ?,FY(B)

(qd "y\"" ?,A(B)

(qd "!/" ?,A!(B)
(qd "$/" ?,A'(B)
(qd "//" ?,Aw(B)
(qd "+/" ?,A1(B)
(qd "-/" ?,A1(B)
(qd "2/" ?,A=(B)
(qd "2." ?,A2(B)
(qd "4/" ?,A<(B)
(qd "<<" ?,A+(B)
(qd "?/" ?,A?(B)
(qd "]/" ?,A,(B)
(qd "./" ?,A$(B)

(quail-setup-current-package)
