/* Support for Non-ASCII Path Name
   Copyright (C) 1985, 1986, 1992, 1993 Free Software Foundation, Inc.

This file is part of GNU Emacs.

GNU Emacs is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 1, or (at your option)
any later version.

GNU Emacs is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Emacs; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */

/* 94.3.9   modified for Mule Ver.1.1 by T.Emami <enami@sys.ptg.sony.co.jp>
	The last arg of encode() should be a pointer to a real Lisp_Object. */
/* 94.6.22  modified for Mule Ver.2.0 by K.Handa <handa@etl.go.jp>
	CONV_BUF_SIZE -> ENCODE_BUF_SIZE/DECODE_BUF_SIZE.
	Macro definition of ITNCODE and AUTOCONV switched. */

#define MCPATH_SOURCE
#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/param.h>

/* mcpath.h should be included in config.h */
#include "config.h"

#ifdef MCPATH_ASSERT			/* for debugging */
#include <assert.h>
#endif

#undef NILP

#ifdef MSDOS  /* 94.8.9  by K.Fujii */
#include <dos.h>
/* #include <jctype.h> */
#ifndef GO32WIN
#include <go32.h>
#include <dpmi.h>
#include <crt0.h>
#include <libc/dosio.h>
#include <fcntl.h>
#endif
#endif

#include "lisp.h"
#include "buffer.h"

#include "charset.h"
#include "coding.h"

Lisp_Object Qpathname_coding_system = 0;

#ifdef DOS_NT  /* 96.5.6  by K.Fujii */
#define MC_DOSTOUNIX_PATHNAME(s,d)					\
  do { unsigned char *_sp = (unsigned char *)(s);			\
        unsigned char *_dp = (unsigned char *)(d);			\
        while (*_sp) { *_dp++ = (*_sp == '\\' ? '/' : *_sp); _sp++; }	\
        *_dp = '\0';							\
  } while (0)
#endif

/* this function should be lisp function. */
DEFUN ("set-pathname-coding-system",
  Fset_pathname_coding_system, Sset_pathname_coding_system,
  1, 1, 0,
  "Set the pathname-coding-system to CODING_SYSTEM.")
  (coding_system)
     register Lisp_Object coding_system;
{
  Fcheck_code (coding_system);
  Fset (Qpathname_coding_system, coding_system);
}

static void mcpath_encode_code (cp)
     coding_type *cp;
{
  Lisp_Object coding_system;

  coding_system = Fsymbol_value (Qpathname_coding_system);

  encode_code (coding_system, cp);
  CODE_CNTL (cp) |= CC_END;	/* 94.6.22 by K.Handa */
}

#ifndef WINDOWSNT  /* 97.3.6  by K.Fujii */
static
#endif
int encode_path_1 (src, srcsize, dst, dstsize)
     unsigned char *src, *dst;
     unsigned int srcsize, dstsize;
{
  coding_type code;

  mcpath_encode_code (&code);
  if (CODE_TYPE (&code) > AUTOCONV)
    {
      unsigned char *buf;

					/* get_conversion_buffer () is not */
					/* re-entrant. */
      buf = (unsigned char *) alloca (ENCODE_BUF_SIZE (srcsize, &code));
      if (buf)
	{
	  int len;
	  Lisp_Object dummy = Qnil; /* 94.3.9 by T.Enami */

	  len = encode (&code, src, buf, srcsize, &dummy);
	  if (!CODE_CHAR (&code) && len <= dstsize)
	    {
	      bcopy (buf, dst, len);
	      return len;
	    }
	}
    }
  return -1;				/* use original */
}

#ifndef WINDOWSNT
static
#endif
unsigned char *decode_path_1 (src, dst, dstsize)
     unsigned char *src, *dst;
     unsigned int dstsize;
{
  coding_type code;

  mcpath_encode_code (&code);
  if (CODE_TYPE (&code) > AUTOCONV)
    {
      int len;
      unsigned char *buf;

      len = strlen (src) + 1;		/* + 1 for '\0' */

					/* get_conversion_buffer () is not */
					/* re-entrant. */
      buf = (unsigned char *) alloca (DECODE_BUF_SIZE (len, &code));
      if (buf)
	{
	  CODE_CNTL (&code) |= CC_END;
	  len = decode (&code, src, buf, len);
	  if (!CODE_CHAR (&code) && len <= dstsize)
	    {
	      bcopy (buf, dst, len);	/* len should include '\0' */
	      return dst;
	    }
	}
    }
  return src;
}

#ifndef DOS_NT  /* 96.4.28, 96.7.23  by K.Fujii */
static
#endif
unsigned char *decode_path (path, ext_path)
     unsigned char *path, ext_path[MC_MAXPATHLEN];
{
  return
    (Qpathname_coding_system
     ? decode_path_1 (path, ext_path, MC_MAXPATHLEN)
     : path);				/* in case of before initialization */
}

/* patch 94.8.9, 97.1.26  by K.Fujii */
#ifdef DOS_NT
unsigned char *encode_path (unsigned char *path,
			    unsigned char *encode_buffer,
			    unsigned int size,
			    int conv_slash)
#else
unsigned char *encode_path (path, encode_buffer, size)
     unsigned char *path;
     unsigned char *encode_buffer;
     unsigned int size;
#endif
{
  int len;

				/* encode up to '\0', the end of string. */
  len = encode_path_1 (path, strlen (path) + 1, encode_buffer, size);
  if (len > 0)
    path = encode_buffer;
#ifdef DOS_NT  /* 96.5.7, 97.1.26  by K.Fujii */
  /* convert the MSDOS style path delimiter to the UNIX style.  Note
     that now the code is *internal*, so we can simply compare each
     character with '\\'.  And this operation will alter the contents
     of Lisp Object, PATH. */
  {
    if (conv_slash)
      {
	unsigned char *p = path;

	while (*p)
	  {
	    if (*p == '\\')
	      *p = '/';
	    p++;
	  }
      }
  }
#endif /* DOS_NT */
  return path;
}
/* end of patch */

/* patch 94.9.4  by K.Fujii */
DEFUN ("encode-path", Fencode_path, Sencode_path, 1, 1, 0,
       "encode the PATH from external code to internal code.\n\
If the system type is MSDOS, path delimter of PATH will be altered.")
  (path)
     Lisp_Object path;
{
  unsigned char encode_buffer[MC_MAXPATHLEN];
  unsigned char *tmp;

  CHECK_STRING (path, 0);

  tmp = encode_path (XSTRING (path)->data,
                    encode_buffer, sizeof (encode_buffer)
#ifdef DOS_NT
		     , 1
#endif
		     );
  if (XSTRING (path)->data != tmp)
    path = build_string (tmp);
  return path;
}
/* end of patch */

#ifndef WINDOWSNT /* 97.3.16  by K.Fujii */
int mc_creat (path, mode)
     unsigned char *path;
     int mode;
{
  unsigned char buffer[MC_MAXPATHLEN];
  return creat (decode_path (path, buffer), mode);
}

#if defined (INTERRUPTABLE_OPEN) || defined (INTERRUPTIBLE_OPEN)
#define open sys_open			/* call open in sysdep.c */
#endif
int mc_open (path, flag, mode)
     unsigned char *path;
     int flag, mode;
{
  unsigned char buffer[MC_MAXPATHLEN];
  return open (decode_path (path, buffer), flag, mode);
}

int mc_access (path, mode)
     unsigned char *path;
     int mode;
{
  unsigned char buffer[MC_MAXPATHLEN];
  return access (decode_path (path, buffer), mode);
}

int mc_chmod (path, mode)
     unsigned char *path;
     int mode;
{
  unsigned char buffer[MC_MAXPATHLEN];
  return chmod (decode_path (path, buffer), mode);
}
#endif /* not WINDOWSNT */

/* if system does not have symbolic links, it does not have lstat.
   In that case, use ordinary stat instead.  */

#ifdef S_IFLNK
int mc_lstat (path, st_addr)
     unsigned char *path;
     struct stat *st_addr;
{
  unsigned char buffer[MC_MAXPATHLEN];
  return lstat (decode_path (path, buffer), st_addr);
}

int mc_readlink (path, buf, size)
     unsigned char *path, *buf;
     int size;
{
  unsigned char buffer[MC_MAXPATHLEN], buffer2[MAXPATHLEN];
  int nread;

  /* decode given `path' into buffer, and get the link contents into
     buffer2. */
  nread = readlink (decode_path (path, buffer), buffer2, MAXPATHLEN);
  if (nread > 0)
    {
      int len;
      unsigned char *result;

      len = encode_path_1 (buffer2, nread, buffer, sizeof (buffer));

      /* if the conversion success and the result fits to `buf', use
         it. */
      if (0 <= len && len <= size)
	{
	  nread = len;
	  result = buffer;
	}
      else			/* use original one. */
	result = buffer2;
	
      bcopy (result, buf, nread);
    }
  return nread;
}
#endif

#ifndef WINDOWSNT /* 97.3.16  by K.Fujii */
#ifndef nec_ews_svr4				/* hir, 1993.10.22 */
int mc_stat (path, st_addr)
#else
int mc_xstat (v, path, st_addr)
     int v;
#endif
     unsigned char *path;
     struct stat *st_addr;
{
  unsigned char buffer[MC_MAXPATHLEN];
#ifndef nec_ews_svr4		/* hir, 1993.10.22 */
  return stat (decode_path (path, buffer), st_addr);
#else
  return _xstat (v, decode_path (path, buffer), st_addr);
#endif
}

int mc_unlink (path)
     unsigned char *path;
{
  unsigned char buffer[MC_MAXPATHLEN];
  return unlink (decode_path (path, buffer));
}

#ifdef HAVE_RENAME
int mc_rename (path, newpath)
     unsigned char *path, *newpath;
{
  unsigned char buffer[MC_MAXPATHLEN], buffer2[MC_MAXPATHLEN];
  return rename (decode_path (path, buffer), decode_path (newpath, buffer2));
}
#endif
#endif /* not WINDOWSNT */

int mc_link (path, newpath)
     unsigned char *path, *newpath;
{
  unsigned char buffer[MC_MAXPATHLEN], buffer2[MC_MAXPATHLEN];
  return link (decode_path (path, buffer), decode_path (newpath, buffer2));
}

#ifndef DOS_NT  /* 94.8.9, 97.1.4  by K.Fujii */
int mc_symlink (path, newpath)
     unsigned char *path, *newpath;
{
  unsigned char buffer[MC_MAXPATHLEN], buffer2[MC_MAXPATHLEN];
  return symlink (decode_path (path, buffer), decode_path (newpath, buffer2));
}
#endif

#ifndef WINDOWSNT /* 97.3.16  by K.Fujii */
int mc_chdir (path)
     unsigned char *path;
{
  unsigned char buffer[MC_MAXPATHLEN];

  path = decode_path (path, buffer);

#ifdef MSDOS  /* 94.8.9  by K.Fujii */
  if ((path[0] != 0) && (path[1] == ':'))
    {
      int drive = (tolower (path[0]) - 'a');
      if (getdisk () != drive)
	setdisk (drive);
    }

  /* If path != "/" and path != "a:/" and path ends with slash, remove
     it. */
  {
    int len = strlen (path);

    if (strcmp (path + 1, ":/") && (len > 1) && (path[len - 1] == '/'))
      {
	if (path != buffer)	/* It is not good to modify original path. */
	  {
	    bcopy (path, buffer, len - 1); /* no need to copy last /. */
	    path = buffer;
	  }
	path[len - 1] = 0;
      }
  }
#endif /* MSDOS */

  return chdir (path);
}
#endif /* not WINDOWSNT */

#ifdef DOS_NT
#ifndef HAVE_GETWD
unsigned char *mc_getcwd (null, size)
     unsigned char *null;		/* in sysdep.c, always 0. */
     size_t size;
{
  unsigned char buffer[MAXPATHLEN];
  unsigned char *path;

  path = (unsigned char *) getcwd ((char *)buffer, MAXPATHLEN);
  if (path)
    {
      /* here, shoule be (path == buffer). */
      path = (unsigned char *) malloc (MC_MAXPATHLEN);	/* MSDOS */
      if (path)
	{
#if 1  /* 96.12.21, 97.1.26  by K.Fujii */
#  ifdef WINDOWSNT
	  if (buffer [0] >= 'A' && buffer [0] <= 'Z' && buffer [1] == ':')
	    buffer [0] += 'a' - 'A';
#  endif
	  if (encode_path (buffer, path, MC_MAXPATHLEN, 1) == buffer)
#else
	  int len;
	  int buffer_length = strlen (buffer) + 1;

	  len = encode_path_1 (buffer, buffer_length, path, MC_MAXPATHLEN);
	  if (len < 0)
#endif
	    {
	      /* conversion failed.  use value that is returned from system. */
	      MC_DOSTOUNIX_PATHNAME (buffer, path); /* 96.5.6  by K.Fujii */
	    }
	}
    }
  return path;
}
#else /* HAVE_GETWD */
unsigned char *mc_getwd (path)
     unsigned char path[];
{
  unsigned char *p;

  p = getwd (path);
  if (p)
    {
      unsigned char buffer[MC_MAXPATHLEN];
#if 1  /* 96.12.21, 97.1.26  by K.Fujii */
#  ifdef WINDOWSNT
      if (*p >= 'A' && *p <= 'Z' && *(p + 1) == ':')
	*p += 'a' - 'A';
#  endif
      if (encode_path (path, buffer, sizeof buffer, 1) != path)
	strcpy (path, buffer);
      else {
	while (*path) {
	  if (*path == '\\') *path = '/';
	  path++;
	}
      }
#else
      int len;
      
      len = encode_path_1 (path, strlen (path) + 1, buffer, sizeof buffer);
      if (len > 0)
	{
	  MC_DOSTOUNIX_PATHNAME (buffer, path);	/* 96.5.6  by K.Fujii */
	}
#endif
    }
  return p;
}
#endif /* HAVE_GETWD */
#endif /* MSDOS */

#ifdef MSDOS  /* 97.1.3  by K.Fujii */
#define spawnve __spawnve

int
mc_spawnve (int mode, char *path, char **argv, char **envv)
{
  unsigned char buffer [MC_MAXPATHLEN];
  unsigned char *tmp = (unsigned char *) alloca (strlen (path) + 1);
  char *p, *p1;

  p = path, p1 = tmp;
  while (*p) {
    *p1++ = (*p == '/' ? '\\' : *p);
    p++;
  }
  *p1 = '\0';
  argv [0] = path = decode_path (tmp, buffer);
  return spawnve (mode, path, argv, envv);
}
#endif

/* In callproc.c, execvp() is called like this:
 * 	execvp (new_argv[0], new_argv);
 * following implement depends this.
 */
#ifndef NO_MC_EXECVP
void mc_execvp (path, argv)
     unsigned char *path, *argv[];
{
  unsigned char buffer[MC_MAXPATHLEN];
  argv[0] = path = decode_path (path, buffer);
  execvp (path, argv);
}
#endif /* !NO_MC_EXECVP */

#ifndef WINDOWSNT /* 97.3.16  by K.Fujii */
DIR *mc_opendir (path)
     unsigned char *path;
{
  unsigned char buffer[MC_MAXPATHLEN];
  return opendir (decode_path (path, buffer));
}

static DIRENTRY mcpath_directory_entry;
DIRENTRY *mc_readdir (d)
     DIR *d;
{
  SYSTEM_DIRENTRY *sp;
  DIRENTRY *dp = &mcpath_directory_entry;

  sp = readdir (d);
  if (!sp) return 0;

#ifndef MSDOS
  dp->d_ino = sp->d_ino;
#endif /* MSDOS */
  {				/* copy d_name with conversion. */
    int len;

    len = encode_path_1 (sp->d_name, NAMLEN (sp),
			 dp->d_name, sizeof (dp->d_name) - 1);
    if (len < 0)
      {
	len = NAMLEN (sp);
#ifdef MCPATH_ASSERT
	assert (len < sizeof (dp->d_name));
#endif
	bcopy (sp->d_name, dp->d_name, len);
      }
    dp->d_name[len] = 0;
#ifdef DOS_NT  /* 97.1.29  by K.Fujii */
    dp->d_namlen = len;
#endif
  }
  return dp;
}

#ifdef HAVE_MKDIR					/* hir, 1994.8.12 */
int mc_mkdir (path, mode)
     unsigned char *path;
     int mode;
{
  unsigned char buffer[MC_MAXPATHLEN];
  return mkdir (decode_path (path, buffer), mode);
}
#endif

#ifdef HAVE_RMDIR					/* hir, 1994.8.12 */
int mc_rmdir (path)
     unsigned char *path;
{
  unsigned char buffer[MC_MAXPATHLEN];
  return rmdir (decode_path (path, buffer));
}
#endif
#endif /* ! WINDOWSNT */

#ifdef DOS_NT  /* 95.2.7, 97.1.4  by K.Fujii */
#ifdef MC_ENV
char * mc_getenv (const char *name)
{
  static unsigned char mc_getenv_val_buffer [1024 * 3];
  unsigned char n_buf[128], v_buf[512];
  unsigned char *val, *val1;
  int size;

  val = getenv (decode_path_1 ((unsigned char *) name,
			       n_buf, sizeof (n_buf)));

  if (val)
    {
      val1 = encode_path (val, v_buf, sizeof (v_buf), 0);
      if (val != val1)
	{
	  strcpy (mc_getenv_val_buffer, val1);
	  val = mc_getenv_val_buffer;
	}
    }
  return (char *)val;
}

int mc_setenv (const char *name, const char *value, int rewrite)
{
  unsigned char n_buf[128], v_buf[256];

  return setenv (decode_path_1 (name, n_buf, sizeof (n_buf)),
		 decode_path_1 (value, v_buf, sizeof (v_buf)),
		 rewrite);
}
#endif /* MC_ENV */

/* Get the default directory for a given drive.  0=def, 1=A, 2=B, ...  */
int
mc_getdefdir (drive, dst)
     int drive;
     char *dst;
{
#ifdef MSDOS /* 96.12.19  by K.Fujii */
  unsigned char tmp [FILENAME_MAX];
  int cflag;

  if (drive != 0) {
    *dst++ = drive +
#if defined (__DJGPP__) & __DJGPP__ > 1
      (_USE_LFN ? 'A' : 'a')
#else
      'a'
#endif
      - 1;
    *dst++ = ':';
  }
  *dst++ = '/';
  *dst = '\0';

  {
#ifdef GO32WIN
    union REGS regs;

    regs.h.dl = drive;
    regs.x.si = (unsigned) tmp;
    regs.h.ah =0x47;
    intdos (&regs, &regs);
    cflag = regs.x.cflag;
#else
    __dpmi_regs dregs;

    dregs.h.dl = drive;
    dregs.x.si = __tb_offset;
    dregs.x.ds = __tb_segment;
    if (_USE_LFN)
      dregs.x.ax = 0x7147;
    else
      dregs.h.ah = 0x47;
    __dpmi_int (0x21, &dregs);
    cflag = (dregs.x.flags & 1);
    if (! cflag)
      dosmemget (__tb, sizeof (tmp), tmp);
#endif
  }
  if (! cflag && tmp [0] != '\0')
    encode_path (tmp, (unsigned char *)dst, MC_MAXPATHLEN, 1);

  return (! cflag);
#else /* not MSDOS */
  unsigned char buffer [MAXPATHLEN];

  if (_getdcwd (drive, buffer, MAXPATHLEN)) {
    if ((buffer [0] >= 'A' && buffer [0] <= 'Z') &&
	buffer [1] == ':')
      buffer [0] += 'a' - 'A';
    if (encode_path (buffer, (unsigned char *) dst, MC_MAXPATHLEN, 1) == buffer)
      MC_DOSTOUNIX_PATHNAME (buffer, dst);
    return 1;
  }
  return 0;
#endif
}
#endif /* DOS_NT */

syms_of_mcpath ()
{
  Qpathname_coding_system = intern ("pathname-coding-system");
  Fset_pathname_coding_system (Qnil);

  defsubr (&Sset_pathname_coding_system);
/* patch 94.9.4  by K.Fujii */
  defsubr (&Sencode_path);
/* end of patch */
}
